# coding: utf-8

"""
    BlackFox

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ConvergencyCriterion(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'number_of_latest_generations': 'int',
        'percentage_of_tolerance': 'float'
    }

    attribute_map = {
        'number_of_latest_generations': 'numberOfLatestGenerations',
        'percentage_of_tolerance': 'percentageOfTolerance'
    }

    def __init__(self, number_of_latest_generations=10, percentage_of_tolerance=5):  # noqa: E501
        """ConvergencyCriterion - a model defined in Swagger"""  # noqa: E501

        self._number_of_latest_generations = None
        self._percentage_of_tolerance = None
        self.discriminator = None

        if number_of_latest_generations is not None:
            self.number_of_latest_generations = number_of_latest_generations
        if percentage_of_tolerance is not None:
            self.percentage_of_tolerance = percentage_of_tolerance

    @property
    def number_of_latest_generations(self):
        """Gets the number_of_latest_generations of this ConvergencyCriterion.  # noqa: E501


        :return: The number_of_latest_generations of this ConvergencyCriterion.  # noqa: E501
        :rtype: int
        """
        return self._number_of_latest_generations

    @number_of_latest_generations.setter
    def number_of_latest_generations(self, number_of_latest_generations):
        """Sets the number_of_latest_generations of this ConvergencyCriterion.


        :param number_of_latest_generations: The number_of_latest_generations of this ConvergencyCriterion.  # noqa: E501
        :type: int
        """

        self._number_of_latest_generations = number_of_latest_generations

    @property
    def percentage_of_tolerance(self):
        """Gets the percentage_of_tolerance of this ConvergencyCriterion.  # noqa: E501


        :return: The percentage_of_tolerance of this ConvergencyCriterion.  # noqa: E501
        :rtype: float
        """
        return self._percentage_of_tolerance

    @percentage_of_tolerance.setter
    def percentage_of_tolerance(self, percentage_of_tolerance):
        """Sets the percentage_of_tolerance of this ConvergencyCriterion.


        :param percentage_of_tolerance: The percentage_of_tolerance of this ConvergencyCriterion.  # noqa: E501
        :type: float
        """

        self._percentage_of_tolerance = percentage_of_tolerance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConvergencyCriterion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
